#include <config.h>
#include "wrappers.h"

char teaseme_digits[] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
      'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j',
      'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't',
      'u', 'v', 'w', 'x', 'y', 'z' };

int sprintInt(char* str, int value) {

  //print the decimal string for value
  int pos = 0;
  int i;
  int radix = 10;
  //int negative = (value < 0) ? 1 : 0;
  //  int orig = value;

  do {
      //This is just an abs( value % radix )

      str[pos++] = teaseme_digits[ ((value % radix) > 0) ? (value % radix) : -(value % radix)];
  } while ((value /= radix) != 0);

  //Now we need to flip the digits around
  str[pos] = '\0';  //First terminate the string

  for(i = 0; i < (pos / 2);i++)
    {
      char temp = str[i];
      str[i] = str[pos - i - 1];
      str[pos - i - 1] = temp;
    }
  //  printk("Generated %s from %i\n", str, orig);
  return 0;
}
